#include <iostream>
#include <fstream>
#include <iomanip>
#include <stdlib.h>
#include <sys/stat.h>
#include "channelflow/flowfield.h"
#include "channelflow/diffops.h"
#include "channelflow/periodicfunc.h"
#include "channelflow/utilfuncs.h"

using namespace std;
using namespace channelflow;

int main(int argc, char* argv[]) {

  string purpose("compute the L2 Distance of two fields");

  ArgList args(argc, argv, purpose);

  const bool   sx      = args.getflag("-sx", "--shiftx", "shift by Lx/2");
  const bool   sz      = args.getflag("-sz", "--shiftz", "shift by Lz/2");
  const string u0name  = args.getstr (2, "<flowfield>", "input field #1");
  const string u1name  = args.getstr (1, "<flowfield>", "input field #2");

  args.check();

  FlowField u0(u0name);
  FlowField u1(u1name);

  u0.makeSpectral();
  u1.makeSpectral();
  if (!u0.congruent(u1))
    cferror("fields are not congruent. exiting");
  if (sx || sz) {
    FieldSymmetry s(sx ? 0.5 : 0.0, sz ? 0.5 : 0.0);
    u1 *= s;
  }

  cout << L2Dist(u0,u1) << endl;
}
