#include <iostream>
#include "channelflow/flowfield.h"
#include "channelflow/diffops.h"

using namespace std;
using namespace channelflow;

int main() {

  bool verbose = true;
  cerr << "ioTest: " << flush;
  if (verbose) {
    cout << "\n====================================================" << endl;
    cout << "ioTest\n\n";
  }

  // Define gridsize
  const int Nx=32;
  const int Ny=33;
  const int Nz=32;

  // Define box size
  const Real Lx=1.75*pi;
  const Real a= -1.0;
  const Real b=  1.0;
  const Real Lz=1.2*pi;


  // Define size and smoothness of initial disturbance
  const Real decay = 0.5;   
  const Real magnitude  = 1.0;   
  const int kxmax = 4;
  const int kzmax = 4;
  const Real maxerr = 1e-14;

  // Construct data fields: 3d velocity and 1d pressure
  cout << "building velocity and pressure fields..." << flush;
  FlowField u(Nx,Ny,Nz,3,Lx,Lz,a,b);
  cout << "done" << endl;

  // Perturb velocity field
  u.perturb(magnitude, decay);
  u *= magnitude/L2Norm(u);
  
  u.binarySave("u");
  
  FlowField v("u");

  Real err = L2Dist(u,v);
  
  if (err < maxerr) {
    cerr << "\t   pass   " << endl;
    cout << "\t   pass   " << endl;
    return 0;
  }
  else {
    cerr << "\t** FAIL **" << endl;
    cout << "\t** FAIL **" << endl;
    cout << "   err == " << err << endl;
    cout << "maxerr == " << maxerr << endl;
    return 1;
  }
}
